#!/usr/bin/env python
# vim: sts=4 sw=4 et
#    This is a component of EMC
#    copyright 2016 Andy Pugh

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA''''''

import os,sys
from gladevcp.persistence import IniFile,widget_defaults,set_debug,select_widgets
import hal
import hal_glib
import gtk
import glib
import linuxcnc
import rsvg
import cairo
import signal

debug = 0

class HandlerClass:


    def on_destroy(self,obj,data=None):
        self.ini.save_state(self)

    def on_restore_defaults(self,button,data=None):
        '''
        example callback for 'Reset to defaults' button
        currently unused
        '''
        self.ini.create_default_ini()
        self.ini.restore_state(self)

    def __init__(self, halcomp,builder,useropts):
        self.halcomp = halcomp
        self.builder = builder
        self.ini_filename = 'savestate.sav'
        self.defaults = {  IniFile.vars: dict(),
                           IniFile.widgets : widget_defaults(select_widgets(self.builder.get_objects(), hal_only=False,output_only = True))
                        }
        self.ini = IniFile(self.ini_filename,self.defaults,self.builder)
        self.ini.restore_state(self)

        self.liststore = self.builder.get_object('liststore1')
        self.cmd = linuxcnc.command()

    def cell_edit(self, row, col, val):
        print row, col, val
        self.liststore[row][col] = val
        print "retrieved value =", self.liststore[row][col]

    def edit1(self, obj, row, val):
        try:
            f = float(val)
            if f > 360 or f < -270:
                self.cell_edit(row, 0, '')
                return
            self.cell_edit(row, 0, '%0.2f'%f)
        except:
            self.cell_edit(row, 0, '')
            return
    def edit2(self, obj, row, val):
        try:
            f = float(val)
            if f > 2000 or f < 0:
                self.cell_edit(row, 1, '')
                return
            self.cell_edit(row, 1, '%0.4f'%f)
        except:
            self.cell_edit(row, 1, '')
            return
    def edit3(self, obj, row, val):
        try:
            f = float(val)
            if f > 180 or f < -180:
                self.cell_edit(row, 2, '')
                return
            self.cell_edit(row, 2, '%0.2f'%f)
        except:
            self.cell_edit(row, 2, '')
            return

    def add_row(self, obj, Data=None):
        self.liststore.append()

    def run(self, obj, Data=None):
        self.cmd.mode(linuxcnc.MODE_MDI)
        bend = 0
        feed = 0
        tilt = 0
        for row in self.liststore:
            if row[0]: bend = row[0]
            if row[1]: feed = row[1]
            if row[2]: tilt = row[2]
            self.cmd.mdi("O<bender> CALL [%s] [%s] [%s]"% (bend, feed, tilt))

def get_handlers(halcomp,builder,useropts):

    global debug
    for cmd in useropts:
        exec cmd in globals()

    set_debug(debug)
    return [HandlerClass(halcomp,builder,useropts)]



